<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>MainWindow</name>
    <message>
        <source>Up</source>
        <translation>Omhoog</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <source>Set</source>
        <translation></translation>
    </message>
    <message>
        <source>Url</source>
        <translation></translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Klaar</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Opmerking</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Soort</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <source>General Options</source>
        <translation>Algemene opties</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Lib</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>Download opties</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Open map</translation>
    </message>
    <message>
        <source>Download Options:</source>
        <translation>Download opties:</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Configureren</translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>Lijstopties ophalen:</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resolutie</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opties</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Select Language</source>
        <translation>Selecteer taal</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>Formaat code</translation>
    </message>
    <message>
        <source>Url To Download</source>
        <translation>Url om te downloaden</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Verversen</translation>
    </message>
    <message>
        <source>Engine&apos;s Default Options</source>
        <translation>Standaardopties van de engine</translation>
    </message>
    <message>
        <source>Playlist Downloader</source>
        <translation>Download speellijst</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Abonnementen</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>Extensie</translation>
    </message>
    <message>
        <source>Recently Used</source>
        <translation>Recent gebruikt</translation>
    </message>
    <message>
        <source>Ui Name</source>
        <translation>Ui naam</translation>
    </message>
    <message>
        <source>Download Path</source>
        <translation>Download pad</translation>
    </message>
    <message>
        <source>Thumbnail</source>
        <translation>Miniatuur</translation>
    </message>
    <message>
        <source>Enter URL:</source>
        <translation>URL invoeren:</translation>
    </message>
    <message>
        <source>Get List</source>
        <translation>Krijg lijst</translation>
    </message>
    <message>
        <source>Basic Downloader</source>
        <translation>Basis Downloader</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation>Standaardinstellingen instellen</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>Programma naam:</translation>
    </message>
    <message>
        <source>Paste Clipboard Content</source>
        <translation>Klembordinhoud plakken</translation>
    </message>
    <message>
        <source>Set Download Options</source>
        <translation>Stel downloadopties in</translation>
    </message>
    <message>
        <source>Batch Downloader</source>
        <translation>Batch downloader</translation>
    </message>
    <message>
        <source>Paste Clipboard Url</source>
        <translation>Klembord-URL plakken</translation>
    </message>
    <message>
        <source>Monitor Clipboard For Url</source>
        <translation>Monitor klembord voor URL</translation>
    </message>
    <message>
        <source>Add Url To List</source>
        <translation>Voeg URL toe aan lijst</translation>
    </message>
    <message>
        <source>Time Interval Start Time(HH:MM:SS):</source>
        <translation>Starttijd tijdsinterval (UU:MM:SS):</translation>
    </message>
    <message>
        <source>Time Interval End Time(HH:MM:SS):</source>
        <translation>Eindtijd tijdsinterval (UU:MM:SS):</translation>
    </message>
    <message>
        <source>Chapters(Comma Separated):</source>
        <translation>Hoofdstukken (door komma&apos;s gescheiden):</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>Opgesplitst in hoofdstukken</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Verberg</translation>
    </message>
    <message>
        <source>Enter Playlist URL:</source>
        <translation>Voer afspeellijst-URL in:</translation>
    </message>
    <message>
        <source>Clear Internal Archive File</source>
        <translation>Wis intern archiefbestand</translation>
    </message>
    <message>
        <source>Use Internal Archive File</source>
        <translation>Gebruik intern archiefbestand</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>home</translation>
    </message>
    <message>
        <source>Show Tray Icon</source>
        <translation>Toon systeemvakpictogram</translation>
    </message>
    <message>
        <source>Auto Save List Of Not Downloaded Media</source>
        <translation>Lijst met niet-gedownloade media automatisch opslaan</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation>Tekstcodering</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>Vooraf ingestelde opties</translation>
    </message>
    <message>
        <source>Reset Option To Its Default</source>
        <translation>Optie herstellen naar de standaardwaarde</translation>
    </message>
    <message>
        <source>Engine&apos;s Name</source>
        <translation>Programmas naam</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standaard</translation>
    </message>
    <message>
        <source>Options To Add</source>
        <translation>Opties om toe te voegen</translation>
    </message>
    <message>
        <source>Url Manager</source>
        <translation>URL-beheerder</translation>
    </message>
    <message>
        <source>Set What Url Should Be Managed By What Engine</source>
        <translation>Stel in welke URL door welke programma moet worden beheerd</translation>
    </message>
    <message>
        <source>Url Filter</source>
        <translation>Url Filter</translation>
    </message>
    <message>
        <source>Website</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum Concurrent Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Hide Downloads When Completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proxy Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Manually Specified Proxy Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get Proxy Configuration From The Environment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manually Specified Proxy Configuration
Example 1: 192.168.93.89:8080
Exampe 2: ${gateway}:8080</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use System Proxy Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Version Info And Autodownload Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Version Info And Latest Version Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Version Info Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do Nothing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Actions At Startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Library Tab</source>
        <translation>Tabblad Bibliotheek inschakelen</translation>
    </message>
    <message>
        <source>Play Downloaded Media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter Playlist Url. To Add Multiple Playlists, Separate Them With A Space Or New Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A Button To Open A Folder To Be Used As A Download Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Theme Config Files Are Stored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Extension&apos;s Binaries Are Stored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Reset These Options To Their Defaults?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme(Need A Restart)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch Between Setting Browser Name And Path To Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show MetaData In Batch Downloader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Download Added Entries In Batch Downloader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify When Download Completes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify When All Downloads Complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Engine&apos;s Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Binary Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Extension Folder</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Destination</source>
        <translation>Bestemming</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Donker</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Russian (Russia)</source>
        <translation>Russich(Rusland)</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Wissen</translation>
    </message>
    <message>
        <source>Email</source>
        <translation></translation>
    </message>
    <message>
        <source>Force Download</source>
        <translation>Forceer download</translation>
    </message>
    <message>
        <source>Save List To File</source>
        <translation>Lijst opslaan in bestand</translation>
    </message>
    <message>
        <source>Get List From File</source>
        <translation>Krijg lijst uit bestand</translation>
    </message>
    <message>
        <source>Found version</source>
        <translation>Gevonden versie</translation>
    </message>
    <message>
        <source>French (France)</source>
        <translation>Frans (Frankrijk)</translation>
    </message>
    <message>
        <source>Media Already In Archive</source>
        <translation>Media al in archief</translation>
    </message>
    <message>
        <source>Failed to download, Following path can not be created: </source>
        <translation>Kan niet downloaden, het volgende pad kan niet worden aangemaakt: </translation>
    </message>
    <message>
        <source>License</source>
        <translation>Licensie</translation>
    </message>
    <message>
        <source>Replies to</source>
        <translation>Antwoorden op</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation></translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>Download opties</translation>
    </message>
    <message>
        <source>Show Log Window</source>
        <translation>Toon log venster</translation>
    </message>
    <message>
        <source>Upload Date:</source>
        <translation>Upload datum:</translation>
    </message>
    <message>
        <source>2. Go To &quot;General Options&quot; Sub Tab.</source>
        <translation>2. Ga naar het subtabblad &quot;Algemene opties&quot;.</translation>
    </message>
    <message>
        <source>Japanese (Japan)</source>
        <translation>Japanees(Japan)</translation>
    </message>
    <message>
        <source>Start Downloading</source>
        <translation>Begin downloading</translation>
    </message>
    <message>
        <source>Download cancelled</source>
        <translation>Download geannuleerd</translation>
    </message>
    <message>
        <source>Download completed</source>
        <translation>Download compleet</translation>
    </message>
    <message>
        <source>Spanish (Spain)</source>
        <translation>Spaans(Spanje)</translation>
    </message>
    <message>
        <source>Polish (Poland)</source>
        <translation>Pools (Polen)</translation>
    </message>
    <message>
        <source>Download</source>
        <translation></translation>
    </message>
    <message>
        <source>Failed to find version information, make sure &quot;%1&quot; is installed and works properly</source>
        <translation>Kan versie-informatie niet vinden, controleer of &quot;%1&quot; is geïnstalleerd en goed werkt</translation>
    </message>
    <message>
        <source>Open Download Folder</source>
        <translation>Open download map</translation>
    </message>
    <message>
        <source>Duration:</source>
        <translation>Looptijd:</translation>
    </message>
    <message>
        <source>Subtitle Name</source>
        <translation>Ondertitel naam</translation>
    </message>
    <message>
        <source>Failed to parse json file from github</source>
        <translation>Kan het json-bestand van github niet ontleden</translation>
    </message>
    <message>
        <source>Turkish (Turkey)</source>
        <translation>Turks(Turkije)</translation>
    </message>
    <message>
        <source>Elapsed Time:</source>
        <translation>Verstreken tijd:</translation>
    </message>
    <message>
        <source>Download Failed</source>
        <translation>Download mislukt</translation>
    </message>
    <message>
        <source>1. Go To &quot;Configure&quot; Tab.</source>
        <translation>1. Ga naar &quot;configuratie&quot; tabblad.</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versie</translation>
    </message>
    <message>
        <source>Chinese (China)</source>
        <translation>Chinees(China)</translation>
    </message>
    <message>
        <source>English (US)</source>
        <translation>Engels(US)</translation>
    </message>
    <message>
        <source>Save Subtitle To File</source>
        <translation>Ondertitel opslaan in bestand</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>Vooraf ingestelde opties</translation>
    </message>
    <message>
        <source>Failed to open file for reading</source>
        <translation>Kan het bestand niet openen om te lezen</translation>
    </message>
    <message>
        <source>Failed To Load A Plugin</source>
        <translation>Laden van plugin mislukt</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>Auteursrechten</translation>
    </message>
    <message>
        <source>Qt Version</source>
        <translation>Qt Versie</translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.</source>
        <translation>Dit programma is gratis software; u kunt het herdistribueren en/of wijzigen onder de voorwaarden van de GNU General Public License zoals gepubliceerd door de Free Software Foundation; hetzij versie 2 van de Licentie, of (naar uw keuze) een latere versie.</translation>
    </message>
    <message>
        <source>This program is distributed in the hope that it will be useful,but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.</source>
        <translation>Dit programma wordt verspreid in de hoop dat het nuttig zal zijn, maar ZONDER ENIGE GARANTIE; zonder zelfs de impliciete garantie van VERKOOPBAARHEID of GESCHIKTHEID VOOR EEN BEPAALD DOEL. Zie de GNU General Public License voor meer details.</translation>
    </message>
    <message>
        <source>To Disable These Checks, Do The Following:-</source>
        <translation>Om deze controles uit te schakelen, doet u het volgende:-</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; requires atleast version &quot;%2&quot; of Media Downloader</source>
        <translation>Programma &quot;%1&quot; vereist minimaal versie &quot;%2&quot; van Media Downloader</translation>
    </message>
    <message>
        <source>Error, executable to backend &quot;%1&quot; could not be found</source>
        <translation>Fout, uitvoerbaar bestand naar backend &quot;%1&quot; kan niet worden gevonden</translation>
    </message>
    <message>
        <source>Error, failed to parse config file &quot;%1&quot;</source>
        <translation>Fout, kan configuratiebestand %1 niet ontleden</translation>
    </message>
    <message>
        <source>Failed to find executable &quot;%1&quot;</source>
        <translation>Kan uitvoerbaar bestand &quot;%1&quot; niet vinden</translation>
    </message>
    <message>
        <source>Failed to find python3 executable for backend &quot;%1&quot;</source>
        <translation>Kan het uitvoerbare bestand van python3 niet vinden voor backend &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Requested Format Is Not Available</source>
        <translation>Gevraagd formaat is niet beschikbaar</translation>
    </message>
    <message>
        <source>Network Error Occured</source>
        <translation>Er is een netwerkfout opgetreden</translation>
    </message>
    <message>
        <source>Invalid Url Entered</source>
        <translation>Ongeldige URL ingevoerd</translation>
    </message>
    <message>
        <source>ErrorCode</source>
        <translation>Foutcode</translation>
    </message>
    <message>
        <source>Download Failed, Engine crashed</source>
        <translation>Download mislukt, programma is gecrasht</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>Formaat code</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>Extensie</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resolutie</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Opmerking</translation>
    </message>
    <message>
        <source>Failed to open file for writing</source>
        <translation>Kan het bestand niet openen om te bewerken</translation>
    </message>
    <message>
        <source>Processing</source>
        <translation>Verwerken</translation>
    </message>
    <message>
        <source>Post Processing</source>
        <translation>Nabewerking</translation>
    </message>
    <message>
        <source>Speed:</source>
        <translation>Snelheid:</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Gedownload</translation>
    </message>
    <message>
        <source>Time Left</source>
        <translation>Tijd over</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>Dit kan erg lang duren</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Methode</translation>
    </message>
    <message>
        <source>Please Update &quot;%1&quot; To Atleast Version &quot;%2&quot;</source>
        <translation>Werk &quot;%1&quot; bij naar ten minste versie &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Extracting archive: </source>
        <translation>Archief uitpakken: </translation>
    </message>
    <message>
        <source>Failed To Extract</source>
        <translation>Kan niet uitpakken</translation>
    </message>
    <message>
        <source>Network Failed To Respond Within %1 seconds</source>
        <translation>Netwerk reageert niet binnen %1 seconden</translation>
    </message>
    <message>
        <source>Update Complete, Restart To Use New Version</source>
        <translation>Update voltooid, herstart om nieuwe versie te gebruiken</translation>
    </message>
    <message>
        <source>File Not Found</source>
        <translation>Bestand niet gevonden</translation>
    </message>
    <message>
        <source>Download complete</source>
        <translation>Download compleet</translation>
    </message>
    <message>
        <source>Resetting download folder to default</source>
        <translation>Downloadmap herstellen naar standaard</translation>
    </message>
    <message>
        <source>Italian (Italy)</source>
        <translation>Italiaans (Italie)</translation>
    </message>
    <message>
        <source>Swedish (Sweden)</source>
        <translation>Zweeds (Zweden)</translation>
    </message>
    <message>
        <source>German (Germany)</source>
        <translation>Duits (Duitsland)</translation>
    </message>
    <message>
        <source>Portuguese (Brazil)</source>
        <translation>Portugees (Brazilie)</translation>
    </message>
    <message>
        <source>Filename with &quot;.txt&quot; Extension Will Save Urls Only</source>
        <translation>Bestandsnaam met de extensie &quot;.txt&quot; slaat alleen URL&apos;s op</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>Programma naam:</translation>
    </message>
    <message>
        <source>Extra Downloading Options</source>
        <translation>Extra downloadopties</translation>
    </message>
    <message>
        <source>Download Time Interval</source>
        <translation>Tijdsinterval downloaden</translation>
    </message>
    <message>
        <source>Download Chapters</source>
        <translation>Hoofdstukken downloaden</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>Opgesplitst in hoofdstukken</translation>
    </message>
    <message>
        <source>Newest Version Is %1, Updating</source>
        <translation>Nieuwste versie %1, Is aan bijwerken</translation>
    </message>
    <message>
        <source>Dutch (Netherlands)</source>
        <translation>Nederlands (Nederland)</translation>
    </message>
    <message>
        <source>Checking installed version of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Found version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 Already Downloaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 Preset Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Best Available Audio Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Best Available Audio Only(MP3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Best Available Audio Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Best Audio With Video Resolution Of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Url Is Not Supported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar.exe&quot; Executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Running In Portable Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Running In Installation Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Path: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>App Data Path: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Open Path For Writing: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Row</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unhide All Hidden Rows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Setting Proxy Server Address Of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsetting Proxy Server Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Engine failed to start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning: Skipping Clipboard Content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Project Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Folders First</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrange In Ascending Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrange By Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrange By Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrange In Descending Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3. Click &quot;Actions At StartUp&quot; Menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4. Select &quot;Do Nothing&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There Is An Update For %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Newest Version Is: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Start Executable %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation type="unfinished">Kopie URL</translation>
    </message>
    <message>
        <source>Open Url With %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Url %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Windows&apos; Secure Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trouble Ahead, Failed To Delete Folder: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other Websites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extract Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extract Audio As MP3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Best Available Audio Only+Thumbnail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Youtube</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autoupdate Disabled For %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Newest Version Is %1, AutoUpdate Disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Author: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Like Count: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Korean (Korea)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sign In To Confirm You Are Not A Bot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show/Hide Controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Merging Audio and Video Together</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remuxing video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Greek (Greece)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Platform Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Completed: %1, Running: %2, Not Started: %3, Succeeded: %4, Failed: %5, Cancelled: %6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stopping Because Media Is Already In Archive File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bulgarien (Bulgaria)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Urls With %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning, Nothing Was Downloaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Cancelled, Playlist Urls Are Not Allowed In This Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Cancelled Because A Condition Was Not Met</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Unknown Reason</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Network Issue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ukrainian (Ukraine)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming &quot;%1&quot; to &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming Failed: %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipping Checking Download Hash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignoring Download Because Hashes Do Not Match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expected &quot;%1&quot; but obtained &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming file to: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar&quot; Executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipping Checking Version Info For Engine &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>basicdownloader</name>
    <message>
        <source>Hide List</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>batchdownloader</name>
    <message>
        <source>Set</source>
        <translation></translation>
    </message>
    <message>
        <source>Open</source>
        <translation></translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>Show Media Options</source>
        <translation>Toon media-opties</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Verwijder</translation>
    </message>
    <message>
        <source>Set Batch File</source>
        <translation>Batchbestand instellen</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Kopie URL</translation>
    </message>
    <message>
        <source>Show Subtitles</source>
        <translation>Toon subtitels</translation>
    </message>
    <message>
        <source>Download</source>
        <translation></translation>
    </message>
    <message>
        <source>Downloading comments</source>
        <translation>Donwload commentaar</translation>
    </message>
    <message>
        <source>Downloading subtitles</source>
        <translation>Download subtitels</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>Toon commentaar</translation>
    </message>
    <message>
        <source>Download Media Part</source>
        <translation>Download media onderdeel</translation>
    </message>
    <message>
        <source>Sort By Date Ascending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort By Date Descending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort By Likes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Set Download Folder</source>
        <translation>Stel download map in</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Verwijder</translation>
    </message>
    <message>
        <source>Select An Engine File</source>
        <translation>Selecteer een engine-bestand</translation>
    </message>
    <message>
        <source>Set As Default</source>
        <translation>Instellen als standaard</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieer</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished">Toevoegen</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation type="unfinished">Standaardinstellingen instellen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annuleer</translation>
    </message>
    <message>
        <source>Select A Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Path To Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <source>Delete</source>
        <translation>Verwijder</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Verwijder alles</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below File?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below Folder?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annuleer</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete All Files And Folders?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Folder To Below Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Selected Items?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>logWindow</name>
    <message>
        <source>Clear</source>
        <translation>Wissen</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluit</translation>
    </message>
    <message>
        <source>Log Window</source>
        <translation>Log venster</translation>
    </message>
</context>
<context>
    <name>playlistdownloader</name>
    <message>
        <source>Open</source>
        <translation></translation>
    </message>
    <message>
        <source>Manage Subscriptions</source>
        <translation>Beheer abonnement</translation>
    </message>
    <message>
        <source>Number of Pages Downloaded</source>
        <translation>Aantal pagina&apos;s downloaden</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleer</translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>Lijstopties ophalen:</translation>
    </message>
    <message>
        <source>Show All Updated</source>
        <translation>Toon alle updates</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Verwijder</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Kopie URL</translation>
    </message>
    <message>
        <source>Downloading video info</source>
        <translation>Downloading video info</translation>
    </message>
    <message>
        <source>Download All Updated</source>
        <translation>Download alle updates</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>Toon commentaar</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>Dit kan even duren</translation>
    </message>
    <message>
        <source>Hide Controls</source>
        <translation>Verberg controls</translation>
    </message>
    <message>
        <source>Show Controls</source>
        <translation>Toon controls</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Toon</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Verberg</translation>
    </message>
</context>
</TS>
